==> amarok-1.80.tar.bz2: amarok-1.80/src/servicebrowser/ServiceCustomActionsCapability.cpp <==
/***************************************************************************
 *   Copyright (c) 2007  Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
 
#include "ServiceCustomActionsCapability.h"
#include "servicemetabase.h"

ServiceCustomActionsCapability::ServiceCustomActionsCapability(CustomActionsProvider * customActionsProvider)
    : Meta::CustomActionsCapability( )
    , m_customActionsProvider( customActionsProvider )
    {}


ServiceCustomActionsCapability::~ServiceCustomActionsCapability()
{
}

QList< QAction * > ServiceCustomActionsCapability::customActions() const
{
        return m_customActionsProvider->customActions();
}

==> amarok-1.86.tar.bz2: amarok-1.86/src/servicebrowser/ServiceCustomActionsCapability.cpp <==
/***************************************************************************
 *   Copyright (c) 2007  Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "ServiceCustomActionsCapability.h"
#include "ServiceMetaBase.h"

ServiceCustomActionsCapability::ServiceCustomActionsCapability(CustomActionsProvider * customActionsProvider)
    : Meta::CustomActionsCapability( )
    , m_customActionsProvider( customActionsProvider )
{
}

ServiceCustomActionsCapability::~ServiceCustomActionsCapability()
{
}

QList< PopupDropperAction * > ServiceCustomActionsCapability::customActions() const
{
        return m_customActionsProvider->customActions();
}
